/**
 * ルーター
 *
 * @author Tsue Shogo
 * @version
 *	1.0.0	2016/08/09(火) 22:17	新規作成
 */
define(function(require){
	// インクルード
	var Container = require('View/Container');
  
	// クラス生成
	return Backbone.Router.extend({
		/**
		 * 初期実行
		 */
		initialize: function(){
			// コンテナインスタンス生成
			this.container = new Container();
		},
		/**
		 * コンテナインスタンス
		 */
		container: null,
		/**
		 * ルーティング
		 */
		routes: function(){
			// ページビュー(callbackName: PageView)
			var PageViews = {
				'index': require('View/pages/index'),
				'news': require('View/pages/news'),
				//'newsDetail': require('View/pages/news/detail'),
				//'contact': require('View/pages/contact')
				// (以下こんな感じで追加)
			};
			// ルーティング(urlPattern: callbackName)
			var viewRoutes = {
				// TOP
				'(/)': 'index',
				'index(/)': 'index',
				// お知らせ一覧
				'news(/)': 'news',
				//// お知らせ詳細
				//'news/:id(/)': 'newsDetail'
				// (以下こんな感じで追加)
			};
			// コールバック関数作成
			var madeCallbackNames = {};
			_.each(viewRoutes, function(callbackName, urlPattern) {
				// 未作成の場合は作成する
				if (typeof(madeCallbackNames[callbackName]) === 'undefined') {
					madeCallbackNames[callbackName] = 1;
					// URLがurlPatternに一致した時に実行
					this.on('route:' + callbackName, function(){
						// 2重実行の防止
						if (this.container.href === location.href) {
							return false;
						}
						this.container.href = location.href;
						// 旧ページビューを保持
						this.container.removeChildViews('oldPageView');
						this.container.views['oldPageView'] = $.extend(true, {}, this.container.views['pageView']);
						// 新ページビュー作成
						var PageView = PageViews[callbackName];
						this.container.views['pageView'] = new PageView();
						this.container.views['pageView'].arguments = arguments;
						this.container.views['pageView'].href = location.href;
						this.container.views['pageView']._GET = {};
						if (location.search !== '') {
							_.each(location.search.slice(1).split('&'), function(str){
								var keys = str.split('=');
								this.container.views['pageView']._GET[keys[0]] = keys[1];
							});
						}
						// 新ページビューの表示・旧ページビューの非表示
						this.container.updatePageView();
					});
				}
			}, this);
			return viewRoutes;
		}
	});
});