/**
 * AppView
 *
 * @author Tsue Shogo
 * @version
 *	1.0.0	2016/08/09(火) 23:05	新規作成
 */
define(function(require){
	// インクルード
	var Backbone = require('backbone');
 
	// クラス生成
	return Backbone.View.extend({
		/**
		 * 初期実行
		 */
		initialize: function(){
		},
		/**
		 * ビュー名
		 */
		name: '',
		/**
		 * テンプレート
		 */
		template: '',
		/**
		 * ビュー
		 */
		views: {},
		/**
		 * コレクション
		 */
		collections: {},
		/**
		 * 所持ビューを削除する
		 *
		 * @param string	viewKey ビューkey
		 * @return void
		 */
		removeChildViews: function(viewKey) {
			_(this.views).each(function(view, key){
				if (typeof(view.cid) !== 'undefined' && ((typeof(viewKey) === 'undefined') || (viewKey === key))) {
					view.removeChildViews();
					view.removeChildCollections();
					view.off();
					view.stopListening();
					view.beforeRemove();
					view.remove();
					delete this.views[key];
				}
			}, this);
			return;
		},
		/**
		 * 所持コレクションを削除する
		 *
		 * @param string	collectionKey   コレクションkey
		 * @return void
		 */
		removeChildCollections: function(collectionKey) {
			_(this.collections).each(function(collection, key){
				if (typeof(collection.cid) !== 'undefined' && ((typeof(collectionKey) === 'undefined') || (collectionKey === key))) {
					collection.off();
					collection.stopListening();
					collection.beforeRemove();
					collection.remove();
					delete this.collections[key];
				}
			}, this);
			return;
		},
		/**
		 * 出力
		 *
		 * @param vars  テンプレート変数
		 * @return this
		 */
		render: function(vars) {
			// HTMLを取得
			try {
				var html = '';
				if (this.template) {
					html = _.template(this.template)(vars);
				}
			} catch (err) {
				console.log(this.name + 'ビューでエラー');
				console.log(err);
				return this;
			}
			// HTMLを出力
			this.$el.html(html);
			// render後処理
			this.afterRender();
			// 終了
			return this;
		},
		/**
		 * render後処理
		 *
		 * @return void
		 */
		afterRender: function() {
		},
		/**
		 * 削除前処理
		 *
		 * @return void
		 */
		beforeRemove: function() {
		}
	});
});